@@ -31,8 +31,6 @@ class MultiLayer:
             if len(data) % number_layers != 0:
                 print('Data given to @MultiLayer has not ' + str(number_layers) + ' layers, as stated')
                 exit()
-            print(len(data))
-            print(len(data) // number_layers)
             size = int(np.sqrt(len(data) // number_layers))
             print('Read in ' + str(number_layers) + ' layers with size ' + str(size))
             # PRESET SpinLattice OBJECTS
@@ -41,6 +39,7 @@ class MultiLayer:
                 self.Layer[m] = SpinLattice(size=size, key='hex', magmom=1.)
             for n in range(len(data)):
                 index_layer = n % number_layers
+                print(index_layer)
                 self.Layer[index_layer].X[n // 2], self.Layer[index_layer].Y[n // 2], self.Layer[index_layer].Z[
                     n // 2] = data[n][0], data[n][1], data[n][2]
                 self.Layer[index_layer].mx[n // 2], self.Layer[index_layer].my[n // 2], self.Layer[index_layer].mz[
