@@ -95,6 +95,9 @@ def skyrmionradius(splat):
     # ================================================================
     # main
     # ================================================================
+    # 0) Test if a skyrmion exists
+    if np.min(splat.mz)>0.0:
+        return None, None, None
     # 1) Find the minimum of magnetisation, as it is nearly the sk center
     index = np.where(splat.mz == min(splat.mz))[0][0]
     # 2) make a 2d fit to mz using sk_2dprofile function
