@@ -16,7 +16,7 @@ def main() -> None:
     - Test precision frequency for two spins from different layers coupled via different types of interlayer exchange:
         [ab, bc, ac, AA, AB, AC]
     """
-    interlayerinteraction=['ab', 'bc', 'ac', 'AA', 'AB', 'AC', 'BA', 'BB', 'BC', 'CA', 'CB', 'CC']
+    interlayerinteraction=['AA']#['ab', 'bc', 'ac', 'AA', 'AB', 'AC', 'BA', 'BB', 'BC', 'CA', 'CB', 'CC']
 
     logfile = Path.cwd() / 'multilayer_tests.log'
     startlogger(logfile)
@@ -26,7 +26,7 @@ def main() -> None:
              'Testing precision of two spins from different layers coupled via interlayer ex. (without damping):')
     for inter in interlayerinteraction:
         writelog(logfile, '=' * 100)
-        l_test = CTestPrecisionWithoutDamping(logfile=logfile, cleanup=True, interlayerinteraction=inter)
+        l_test = CTestPrecisionWithoutDamping(logfile=logfile, cleanup=False, interlayerinteraction=inter)
         writelog(logfile, message=repr(l_test))
         result = l_test()
 
